OC.L10N.register(
    "core",
    {
    "Please select a file." : "Изаберите фајл.",
    "File is too big" : "Фајл је превелик",
    "The selected file is not an image." : "Изабрани фајл није слика.",
    "The selected file cannot be read." : "Није могуће читати изабрани фајл.",
    "Invalid file provided" : "Понуђени фајл није исправан",
    "No image or file provided" : "Нису понуђени ни слика ни фајл",
    "Unknown filetype" : "Непознат тип фајла",
    "Invalid image" : "Неисправна слика",
    "An error occurred. Please contact your admin." : "Дошло је до грешке. Контактирајте администратора.",
    "No temporary profile picture available, try again" : "Нема привремене слике профила. Покушајте поново",
    "No crop data provided" : "Нема података о опсецању",
    "No valid crop data provided" : "Нема исправних података о опсецању",
    "Crop is not square" : "Опсецање није квадратног облика",
    "State token does not match" : "Стање жетона се не слаже",
    "Could not complete login" : "Не могу да довршим пријављивање",
    "Your login token is invalid or has expired" : "Ваш токен за пријављивање је неисправан или је истекао",
    "Password reset is disabled" : "Ресетовање лозинке није омогућено",
    "Couldn't reset password because the token is invalid" : "Није могуће ресетовање лозинке јер je жетон неважећи",
    "Couldn't reset password because the token is expired" : "Није могуће ресетовање лозинке јер је жетон истекао",
    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Није могуће послати е-пошту за ресетовање лозинке јер није подешена адреса е-поште за овог корисника. Контактирајте администратора.",
    "%s password reset" : "%s лозинка ресетована",
    "Password reset" : "Ресетовање лозинке",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Кликните следеће дугме за ресетовање лозинке. Ако нисте тражили ресетовање лозинке, занемарите ову поруку.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Кликните следећу везу за ресетовање лозинке. Ако нисте тражили ресетовање лозинке, занемарите ову поруку.",
    "Reset your password" : "Ресетуј лозинку",
    "Couldn't send reset email. Please contact your administrator." : "Не могу да пошаљем поруку за ресетовање. Контактирајте администратора.",
    "Couldn't send reset email. Please make sure your username is correct." : "Не могу да пошаљем поруку за ресетовање. Проверите да ли је корисничко име исправно.",
    "Some of your link shares have been removed" : "Неке од Ваших веза дељења су уклоњене",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Уклонили смо неке од Ваших веза дељења због безбедоносног пропуста. Погледајте везу да добијете више информација.",
    "Preparing update" : "Припремам ажурирање",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Корак поправке:",
    "Repair info:" : "Инфо о поправци:",
    "Repair warning:" : "Упозорење о поправци :",
    "Repair error:" : "Грешка поправке:",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Ажурирање урадите преко командне линије јер је аутоматско ажурирање онемогућено у config.php.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Проверавам табелу %s",
    "Turned on maintenance mode" : "Режим одржавања укључен",
    "Turned off maintenance mode" : "Режим одржавања искључен",
    "Maintenance mode is kept active" : "Режим одржавања се држи активним",
    "Updating database schema" : "Освежава се шема базе података",
    "Updated database" : "База података ажурирана",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Провера да ли шема базе података може да се ажурира (ово може потрајати, у зависности колика је база)",
    "Checked database schema update" : "Проверено ажурирање шеме базе података",
    "Checking updates of apps" : "Проверавам ажурирања апликација",
    "Checking for update of app \"%s\" in appstore" : "Проверавам ажурирања апликације „%s“ у продавници",
    "Update app \"%s\" from appstore" : "Ажурирај апликацију „%s“ из продавнице",
    "Checked for update of app \"%s\" in appstore" : "Проверено ажурирање апликације „%s“ у продавници",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Провера да ли шема база за %s може бити ажурирана (ово може да потраје, у зависности колика је база)",
    "Checked database schema update for apps" : "Проверено ажурирање шеме базе података за апликације",
    "Updated \"%1$s\" to %2$s" : "„%1$s“ ажурирано на %2$s",
    "Set log level to debug" : "Постави ниво уписа у дневник на дебаговање",
    "Reset log level" : "Поништи ниво уписа у дневник",
    "Starting code integrity check" : "Почиње провера интегритета кода",
    "Finished code integrity check" : "Завршена провера интегритета кода",
    "%s (incompatible)" : "%s (некомпатибилан)",
    "Following apps have been disabled: %s" : "Следеће апликације су онемогућене: %s",
    "Already up to date" : "Већ има последњу верзију",
    "Very weak password" : "Веома слаба лозинка",
    "Weak password" : "Слаба лозинка",
    "So-so password" : "Осредња лозинка",
    "Good password" : "Добра лозинка",
    "Strong password" : "Јака лозинка",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Ваш сервер није правилно подешен да омогући синхронизацију фајлова. Изгледа да је ВебДАВ сучеље покварено.",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Ваш сервер није правилно подешен да разлучи „{url}“. Можете наћи више информација у <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">документацији</a>.",
    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation page</a>. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Ваш сервер није подешен да може да разлучи адресу „{url}“. Ово је најчешће везано за неажурирану конфигурацију веб сервера која не може да испоручи ову фасциклу директно. Упоредите Вашу конфигурацију са испорученим rewrite правилима у „.htaccess“-у за Apache или онима датим за Nginx у његовој <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">документацији</a>. На Nginx-у су обично линије које почињу са „location ~“ оне којима треба ажурирање.",
    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Ваш веб сервер није правилно подешен да испоручује .woff2 фајлове. Ово је обично проблем са Nginx конфигурацијом. У Некстклауду 15, потребна су додатна прилагођавања да се и .woff2 фајлови испоручују. Упоредите Вашу Nginx конфигурацију са препорученом конфигурацијом из наше <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">документације</a>.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP изгледа није исправно подешен да дохвата променљиве окружења. Тест са getenv(\"PATH\") враћа празну листу као одговор.",
    "Please check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">installation documentation ↗</a> for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Погледајте <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">инсталациону документацију ↗</a> за белешке око PHP конфигурације и PHP конфигурацију Вашег сервера, поготову ако користите php-fpm.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Омогућена је конфигурација само за читање. То спречава постављање неке конфигурације преко веб-интерфејса. Осим тога, фајлу мора бити ручно омогућено уписивање код сваког освежавања.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "База података није покренута са „READ COMMITTED“ нивоом изолације трансакција. Ово може изазвати проблеме ако се више различитих акција изврши у паралели.",
    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "Недостаје PHP модул „fileinfo“. Препоручујемо да га укључите да бисте добили најбоље резултате с откривањем MIME типова фајлова.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation ↗</a> for more information." : "Трансактивно закључавање фајлова је искључено, што може довести до проблема са утркивањем процеса. Укључите 'filelocking.enabled' у config.php да бисте избегли проблеме овог типа. Погледајте <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">документацију ↗</a> за више информација.",
    "If your installation is not installed at the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (suggestion: \"{suggestedOverwriteCliURL}\")" : "Ако инсталација није инсталирана у основи домена и користи системски крон, може бити проблема са генерисањем веб адреса. Да бисте избегли ове проблеме, молимо вас да подесите „overwrite.cli.url“ опцију у вашем  config.php фајлу у путању веб-основе ваше инсталације (предложено: \"{suggestedOverwriteCliURL}\")",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Није било могуће да се изврши крон задатак путем интерфејса командне линије. Појавиле су се следеће техничке грешке:",
    "Last background job execution ran {relativeTime}. Something seems wrong." : "Последњи извршени посао у позадини: {relativeTime}. Нешто изгледа није у реду.",
    "Check the background job settings" : "Проверите поставке послова у позадини",
    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Овај сервер нема интернет конекцију: немогуће је доћи до више интернет крајњих тачака. Ово значи да неке могућности као што су качење спољних складишта, обавештења о ажурирањима или инсталација апликација треће стране неће радити. Приступање фајловима споља и слање обавештења е-поштом исто тако може да не ради. Омогућите интернет конекцију на овом серверу ако желите да уживате у свим могућностима.",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Нисте подесили меморијски кеш. Да побољшате перформансе, подесите меморијски кеш, ако је доступан. Више информација има у <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">документацији</a>.",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "PHP не може да чита погодан извор случајних бројева што се не препоручује из сигурносних разлога. Можете наћи више информација у <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">документацији</a>.",
    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "Тренутно користите {version} верзију PHP-а. Надоградите PHP верзију да искористите сва <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">безбедоносна ажурирања и побољшања брзине које обезбеђује PHP група</a>, чим Ваша дистрибуција почне да је подржава.",
    "You are currently running PHP 5.6. The current major version of Nextcloud is the last that is supported on PHP 5.6. It is recommended to upgrade the PHP version to 7.0+ to be able to upgrade to Nextcloud 14." : "Тренутно користите PHP верзију 5.6. Тренутна главна верзија Некстклауда је последња која подржава PHP 5.6. Препорука је да пређете на PHP верзију 7.0+ да бисте могли да ажурирате Некстклауд на верзију 14.",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Или подешавање обрнутих прокси заглавља није исправно, или приступате Некстклауду преко проксија од поверења. Ако то не радите, ово је безбедоносни проблем и може омогућити нападачу да лажира да је његова IP адреса видљива Некстклауду. Више информација о овоме има у <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">документацији</a>.",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached је подешен као дистрибуирани кеш, али је инсталиран погрешни PHP модуле „memcache“. \\OC\\Memcache\\Memcached подржава само \"memcached\" модул, а не и \"memcache\".  Погледајте <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{wikiLink}\">memcached вики о оба модула</a>.",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Неки фајлови нису прошли проверу интегритета. Даљње информације о томе како да решите овај проблем се могу наћи у <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">документацији</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Списак неисправних фајлова</a>/<a href=\"{rescanEndpoint}\">Скенирај поново…</a>)",
    "The PHP OPcache module is not loaded. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">For better performance it is recommended</a> to load it into your PHP installation." : "The PHP OPcache модул није учитан. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">За боље перформансе препоручује се</a> да га учитате у Вашу PHP инсталацију.",
    "The PHP OPcache is not properly configured. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">For better performance it is recommended</a> to use the following settings in the <code>php.ini</code>:" : "PHP OPcache није подешен исправно. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">За боље перформансе предлаже се</a> да користите следећа подешавања у <code>php.ini</code> фајлу:",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP функција „set_time_limit“ није доступна. Ово може да узрокује да се скрипте закоче у сред извршавања, и тако покваре инсталацију. Препоручује се да омогућите ову функцију.",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Ваша PHP инсталација нема подршку за FreeType. Ово ће довести до неисправних профилних слика и неисправног интерфејса за подешавања.",
    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Индекс „{indexName}“ недостаје у табели „{tableName}“.",
    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "У бази недостају поједини индекси. Због тога што додавање индекса на великим табелама може доста да потраје, индекси се не додају аутоматски. Покретањем „occ db:add-missing-indices“, индекси који недостају ће бити додати ручно док је инстанца покренута. Једном када су индекси додати, упити над тим табелама ће обично бити много бржи.",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "Овој инстанци недостају неки препоручени PHP модули. Препоручује се да их инсталирате због побољшања перформанси и за бољу компатибилност.",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running 'occ db:convert-filecache-bigint' those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">the documentation page about this</a>." : "Неке колоне у бази нису пребачене у big int тип. Пошто промена типа колоне може доста да потраје на великим табелама, оне нису аутоматски промењене. Покретањем команде 'occ db:convert-filecache-bigint' ће се ове преостале измене применити. Ова операција се мора урадити док инстанца не ради. За више детаља, прочитајте <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">документацију о овоме</a>.",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "Тренутно се као база података користи SQLite. За веће инсталације, препоручујемо да промените базу података.",
    "This is particularly recommended when using the desktop client for file synchronisation." : "Ово се нарочито порепоручује ако се користи клијент програм у графичком окружењу за синхронизацију.",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation ↗</a>." : "За пресељење на другу базу података, користите алат командне линије:  'occ db:convert-type', или погледајте <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">документацију ↗</a>.",
    "Use of the the built in php mailer is no longer supported. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Please update your email server settings ↗<a/>." : "Коришћење уграђеног php mailer-а више није подржано. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Молимо ажурирајте и-мејл сервер поставке ↗<a/>.",
    "The PHP memory limit is below the recommended value of 512MB." : "Меморијски лимит PHP-а је испод препоручене вредности од 512MB.",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Власник неких апликативних директоријума је корисник који није исти као и корисник по којим ради веб сервер. Ово је могуће ако су се апликације инсталирале ручно. Проверите привилегије над следећим апликативним директоријумима:",
    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">the documentation page about this</a>." : "MySQL се користи као база података, али она не подржава карактере од 4 бајта. Да бисте могли да користите ове 4-бајтне карактере (као што су емоџији) без проблема у нпр. именима фајлова или коментарима, препоручује се да омогућите подршку за 4 бајта у MySQL-у. За више детаља, прочитајте <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">страну на документацији о овоме</a>.",
    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "Ова инстанца користи S3 базирано чување података за основно складиште. Отпремљени фајлови се привремено чувају на серверу и препоручује се да имате доступно бар 50 GB слободног простора у PHP привременом директоријуму. Погледајте дневник за више детаља око путања и слободном простору. Да бисте ово променили или побољшали, измените привремени директоријум у php.ini фајлу или направите више слободног места на тренутној путањи.",
    "Error occurred while checking server setup" : "Дошло је до грешке при провери поставки сервера",
    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Ваша фасцикла са подацима и фајлови су вероватно доступни са интернета. .htaccess фајл не ради. Препоручујемо да подесите Ваш веб сервер тако да је фасцикла са подацима ван фасцикле кореног документа веб сервера.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP заглавље „{header}“ није подешено као „{expected}“. Ово потенцијално угрожава безбедност и приватност и препоручује се да подесите ову поставку.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "HTTP заглавље „{header}“ није подешено као „{expected}“. Неке функције можда неће радити исправно, па препоручује се да подесите ову поставку.",
    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP заглавље „{header}“ не садржи „{expected}“. Ово потенцијално угрожава безбедност и приватност и препоручује се да подесите ову поставку.",
    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C Recommendation ↗</a>." : "HTTP заглавље \"{header}\" није постављено на \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" или \"{val5}\". Овиме могу процурети информације о рефералу. Погледајте <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C препоруке↗</a>",
    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the <a href=\"{docUrl}\" rel=\"noreferrer noopener\">security tips ↗</a>." : "\"Strict-Transport-Security\" HTTP заглавље није подешено да буде бар \"{seconds}\" секунди. За додатну сигурност, предлаже се да омогућите HSTS као што је описано у <a href=\"{docUrl}\" rel=\"noreferrer noopener\">сигурносним саветима↗</a>.",
    "Accessing site insecurely via HTTP. You are strongly adviced to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips ↗</a>." : "Приступање сајту преко HTTP-а. Препоручује се да подесите Ваш сервер да захтева HTTPS као што је описано у <a href=\"{docUrl}\">безбедоносним саветима↗</a>",
    "Shared" : "Дељено",
    "Shared with" : "Дељено са",
    "Shared by" : "Поделио",
    "Choose a password for the public link" : "Унесите лозинку за јавну везу",
    "Choose a password for the public link or press the \"Enter\" key" : "Унесите лозинку за јавну везу или притисните \"Ентер\"",
    "Copied!" : "Копирано!",
    "Copy link" : "Копирај везу",
    "Not supported!" : "Није подржано!",
    "Press ⌘-C to copy." : "Притисни ⌘-C за копирање.",
    "Press Ctrl-C to copy." : "Притисни Ctrl-C за копирање.",
    "Copy" : "Копирај",
    "Unable to create a link share" : "Не могу да направим везу дељења",
    "Unable to toggle this option" : "Не могу да укључим/искључим ову опцију",
    "Resharing is not allowed" : "Поновно дељење није дозвољено",
    "Link" : "Веза",
    "Hide download" : "Сакриј скидање",
    "Password protection enforced" : "Захтевана заштита лозинком",
    "Password protect" : "Заштићено лозинком",
    "Password" : "Лозинка",
    "Allow editing" : "Дозволи уређивање",
    "Email link to person" : "Пошаљи е-поштом",
    "Send" : "Пошаљи",
    "Allow upload and editing" : "Дозволи отпремање и уређивање",
    "Read only" : "Само за читање",
    "File drop (upload only)" : "Превлачење фајлова (само за отпремање)",
    "Expiration date enforced" : "Захтевано постављање датума истека",
    "Set expiration date" : "Постави датум истека",
    "Expiration" : "Истиче",
    "Expiration date" : "Датум истека",
    "Note to recipient" : "Белешка примаоцу",
    "Unshare" : "Укини дељење",
    "Delete share link" : "Обриши везу дељења",
    "Add another link" : "Додај још једну везу",
    "Password protection for links is mandatory" : "За везе је обавезна заштита лозинком",
    "Share to {name}" : "Подели са {name}",
    "Share link" : "Веза дељења",
    "New share link" : "Нова веза дељења",
    "Created on {time}" : "Направљено {time}",
    "Password protect by Talk" : "Заштити лозинком преко Talk-а",
    "Could not unshare" : "Не могу да укинем дељење",
    "Shared with you and the group {group} by {owner}" : "{owner} дели са вама и са групом {group}.",
    "Shared with you and {circle} by {owner}" : "Дељемп са Вама и кругом {circle} од стране корисника {owner}",
    "Shared with you and the conversation {conversation} by {owner}" : "{owner} поделио са Вама и у разговору {conversation}",
    "Shared with you in a conversation by {owner}" : "{owner} поделио са Вама у разговору",
    "Shared with you by {owner}" : "{owner} дели са вама",
    "Choose a password for the mail share" : "Изаберите лозинку за дељење е-поштом",
    "group" : "група",
    "remote" : "удаљени",
    "remote group" : "удаљена група",
    "email" : "е-пошта",
    "conversation" : "разговор",
    "shared by {sharer}" : "поделио је {sharer}",
    "Can reshare" : "Може да дели даље",
    "Can edit" : "Може да мења",
    "Can create" : "Може да направи",
    "Can change" : "Може да мења",
    "Can delete" : "Може да брише",
    "Access control" : "Контрола приступа",
    "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} је поделио преко везе",
    "Error while sharing" : "Грешка при дељењу",
    "Share details could not be loaded for this item." : "Не могу да учитам детаље дељења за ову ставку.",
    "Search globally" : "Претражите глобално",
    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Најмање {count} слово је потребно за аутокомплетирање","Најмање {count} слова је потребно за аутокомплетирање","Најмање {count} слова је потребно за аутокомплетирање"],
    "This list is maybe truncated - please refine your search term to see more results." : "Ова листа је можда скраћена - претражите опет користећи мало специфичније изразе да бисте добили још резултата.",
    "No users or groups found for {search}" : "Није нађен ниједан корисник ни група за претрагу {search}",
    "No users found for {search}" : "Није нађен ниједан корисник за претрагу {search}",
    "An error occurred (\"{message}\"). Please try again" : "Десила се грешка (\"{message}\"). Покушајте поново.",
    "An error occurred. Please try again" : "Дошло је до грешке. Покушајте поново",
    "Home" : "Почетна",
    "Work" : "Посао",
    "Other" : "Остало",
    "{sharee} (remote group)" : "{sharee} (удаљена група)",
    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
    "Share" : "Дели",
    "Name or email address..." : "Име или адреса е-поште...",
    "Name or federated cloud ID..." : "Име или ID здруженог облака...",
    "Name, federated cloud ID or email address..." : "Име, ID здруженог облака или адреса е-поште...",
    "Name..." : "Име...",
    "Error" : "Грешка",
    "Error removing share" : "Грешка при уклањању дељења",
    "Non-existing tag #{tag}" : "Непостојећа ознака #{tag}",
    "restricted" : "ограничен",
    "invisible" : "невидљив",
    "({scope})" : "({scope})",
    "Delete" : "Обриши",
    "Rename" : "Преименуј",
    "Collaborative tags" : "Групне ознаке",
    "No tags found" : "Ознаке нису нађене",
    "unknown text" : "непознат текст",
    "Hello world!" : "Здраво свете!",
    "sunny" : "сунчано",
    "Hello {name}, the weather is {weather}" : "Здраво {name}, време је {weather}",
    "Hello {name}" : "Здраво {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Ово су резултати Ваше претраге<script>alert(1)</script></strong>",
    "new" : "ново",
    "_download %n file_::_download %n files_" : ["преузми %n фајл","преузми %n фајла","преузми %n фајлова"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Ажурирање је у току. У неким окружењима, напуштање ове стране може да прекине овај процес.",
    "Update to {version}" : "Ажурирај на {version}",
    "An error occurred." : "Дошло је до грешке.",
    "Please reload the page." : "Поново учитајте страницу.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Ажурирање није успело. За више информација <a href=\"{url}\">проверите нашу објаву на форуму</a> која обрађује ову тему.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Ажурирање није успело. Молимо пријавите овај проблем <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Некстклауд заједници</a>.",
    "Continue to Nextcloud" : "Наставите на Некстклауд",
    "_The update was successful. Redirecting you to Nextcloud in %n second._::_The update was successful. Redirecting you to Nextcloud in %n seconds._" : ["Надоградња је била успешна. Враћање на Некстклауд за %n секунду.","Надоградња је била успешна. Враћање на Некстклауд за %n секунде.","Ажурирање је било успешно. Враћање на Некстклауд за %n секунди."],
    "Searching other places" : "Претражујем остала места",
    "No search results in other folders for {tag}{filter}{endtag}" : "Нема резултата претраге у осталим фасциклама за {tag}{filter}{endtag}",
    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} резултат претраге у осталим фасциклама","{count} резултата претраге у осталим фасциклама","{count} резултата претраге у осталим фасциклама"],
    "Server side authentication failed!" : "Потврда идентитета на серверу није успела!",
    "Please contact your administrator." : "Контактирајте вашег администратора.",
    "An internal error occurred." : "Догодила се унутрашња грешка. ",
    "Please try again or contact your administrator." : "Покушајте поново или контактирајте вашег администратора.",
    "Username or email" : "Корисничко име или адреса е-поште",
    "Username or\temail" : "Корисничко име или\tадреса е-поште",
    "Log in" : "Пријава",
    "Logging in …" : "Пријављивање ...",
    "Wrong username or password." : "Погрешно корисничко име или лозинка",
    "User disabled" : "Корисник онемогућен",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Приметили смо више неисправних покушаја пријава са Ваше IP адресе. Следећа пријава ће бити могућа тек за 30 секунди.",
    "Reset password" : "Ресетуј лозинку",
    "If it is not there ask your local administrator." : "Ако није ни тамо, контактирајте вашег администратора.",
    "Password can not be changed. Please contact your administrator." : "Лозинка се не може променити. Контактирајте администратора.",
    "Back to login" : "Назад на пријаву",
    "Forgot password?" : "Заборавили сте лозинку?",
    "Settings" : "Поставке",
    "Could not load your contacts" : "Не могу да учитам Ваше контакте",
    "Search contacts …" : "Претражи контакте ...",
    "No contacts found" : "Контакти нису нађени",
    "Show all contacts …" : "Прикажи све контакте ...",
    "Loading your contacts …" : "Учитавам контакте ...",
    "Looking for {term} …" : "Тражим {term} …",
    "No" : "Не",
    "Yes" : "Да",
    "No files in here" : "Овде нема фајлова",
    "New folder" : "Нова фасцикла",
    "No more subfolders in here" : "Овде више нема потфасцикли",
    "Name" : "Назив",
    "Size" : "Величина",
    "Modified" : "Измењен",
    "{newName} already exists" : "{newName} већ постоји",
    "Choose" : "Изаберите",
    "Move" : "Премести",
    "Error loading file picker template: {error}" : "Грешка при учитавању шаблона бирача фајлова: {error}",
    "OK" : "У реду",
    "Error loading message template: {error}" : "Грешка при учитавању шаблона поруке: {error}",
    "read-only" : "само-за-читање",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} сукоб фајлова","{count} сукоба фајлова","{count} сукоба фајлова"],
    "One file conflict" : "Један сукоб фајлова",
    "New Files" : "Нови фајлови",
    "Already existing files" : "Постојећи фајлови",
    "Which files do you want to keep?" : "Које фајлове желите да задржите?",
    "If you select both versions, the copied file will have a number added to its name." : "Ако изаберете обе верзије, копираном фајлу ће бити додат број у називу.",
    "Cancel" : "Одустани",
    "Continue" : "Настави",
    "(all selected)" : "(све изабрано)",
    "({count} selected)" : "(изабрано: {count})",
    "Error loading file exists template" : "Грешка при учитавању шаблона „Фајл постоји“",
    "Pending" : "На чекању",
    "Copy to {folder}" : "Копирај у {folder}",
    "Move to {folder}" : "Премести у {folder}",
    "Saving..." : "Чувам...",
    "Authentication required" : "Неопходна провера идентитета",
    "This action requires you to confirm your password" : "Ова радња захтева да потврдите лозинку",
    "Confirm" : "Потврди",
    "Failed to authenticate, try again" : "Неуспешна провера идентитета, покушајте поново",
    "seconds ago" : "пре пар секунди",
    "Connection to server lost" : "Изгубљена је веза са сервером",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Грешка приликом учитавања стране, пробам поново за %n секунду","Грешка приликом учитавања стране, пробам поново за %n секунде","Грешка приликом учитавања стране, пробам поново за %n секунди"],
    "Add to a project" : "Додај у пројекат",
    "Show details" : "Прикажи детаље",
    "Hide details" : "Сакриј детаље",
    "Rename project" : "Преименуј пројекат",
    "Failed to rename the project" : "Грешка при преименовању пројекат",
    "Failed to create a project" : "Грешка при креирању пројекта",
    "Failed to add the item to the project" : "Грешка приликом додавања ставке у пројекат",
    "Connect items to a project to make them easier to find" : "Повежите ставке у пројекат да Вам буде лакше да их нађете",
    "Type to search for existing projects" : "Крените да куцате да тражите постојеће пројекте",
    "New in" : "Ново у",
    "View changelog" : "Погледајте дневник измена",
    "No action available" : "Нема доступне радње",
    "Error fetching contact actions" : "Грешка приликом дохватања акција над контактима",
    "Personal" : "Лично",
    "Users" : "Корисници",
    "Apps" : "Апликације",
    "Admin" : "Администрација",
    "Help" : "Помоћ",
    "Access forbidden" : "Забрањен приступ",
    "File not found" : "Фајл није нађен",
    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Овај документ није нађен на серверу. Можда је дељење избрисано или му је истекао рок трајања?",
    "Back to %s" : "Назад на %s",
    "Internal Server Error" : "Унутрашња грешка сервера",
    "The server was unable to complete your request." : "Сервер не може да обради Ваш захтев.",
    "If this happens again, please send the technical details below to the server administrator." : "Ако се ово понови, пошаљите техниче детаље испод администратору овог сервера.",
    "More details can be found in the server log." : "Више детаља се може наћи у дневнику сервера.",
    "Technical details" : "Технички детаљи",
    "Remote Address: %s" : "Удаљена адреса: %s",
    "Request ID: %s" : "ID захтева: %s",
    "Type: %s" : "Тип: %s",
    "Code: %s" : "Кôд: %s",
    "Message: %s" : "Порука: %s",
    "File: %s" : "Фајл: %s",
    "Line: %s" : "Линија: %s",
    "Trace" : "Траг",
    "Security warning" : "Безбедносно упозорење",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Ваш директоријум са подацима и фајлови су вероватно доступни са интернета јер .htaccess не ради.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "За информације како да правилно подесите Ваш сервер, погледајте <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">документацију</a>.",
    "Create an <strong>admin account</strong>" : "Направи <strong>административни налог</strong>",
    "Username" : "Корисничко име",
    "Storage & database" : "Складиште и база података",
    "Data folder" : "Фасцикла за податке",
    "Configure the database" : "Подешавање базе",
    "Only %s is available." : "Само %s је доступна.",
    "Install and activate additional PHP modules to choose other database types." : "Инсталирајте и активирајте додатне PHP модуле за одабир других база података.",
    "For more details check out the documentation." : "За више детаља погледајте документацију.",
    "Database user" : "Корисник базе",
    "Database password" : "Лозинка базе",
    "Database name" : "Назив базе",
    "Database tablespace" : "Радни простор базе података",
    "Database host" : "Домаћин базе",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Наведите и број порта у имену домаћина (нпр. localhost:5432).",
    "Performance warning" : "Упозорење о перформансама",
    "You chose SQLite as database." : "Одабрали сте SQLite за базу података.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite треба да се користи само за најмање инстанце или за инстанце за развој. За продукцију, препоручујемо други тип база података.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Коришћење SQLite базе података нарочите није препоручљиво ако користите клијенте за синхронизацију фајлова.",
    "Finish setup" : "Заврши подешавање",
    "Finishing …" : "Завршавам…",
    "Need help?" : "Треба Вам помоћ?",
    "See the documentation" : "Погледајте документацију",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Делује као да покушавате да реинсталирате Некстклауд. Међутим, фајл CAN_INSTALL фали из конфигурационог директоријума, Молимо креирајте фајл CAN_INSTALL у овом директоријуму да бисте наставили.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Не могу да уклоним CAN_INSTALL из конфигурационе фасцикле. Уклоните овај фајл ручно.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Ова апликација захтева Јава скрипт за исправан рад. {linkstart}Омогућите Јава скрипт{linkend} и поново учитајте страницу.",
    "Get your own free account" : "Узмите бесплатан налог",
    "Skip to main content" : "Прескочи на главни садржај",
    "Skip to navigation of app" : "Прескочи на навигацију апликације",
    "More apps" : "Још апликација",
    "More" : "Још",
    "More apps menu" : "Мени још апликација",
    "Search" : "Претражи",
    "Reset search" : "Ресетуј претрагу",
    "Contacts" : "Контакти",
    "Contacts menu" : "Мени контаката",
    "Settings menu" : "Мени подешавања",
    "Confirm your password" : "Потврдите лозинку",
    "Connect to your account" : "Повежите се на Ваш налог",
    "Please log in before granting %1$s access to your %2$s account." : "Прво се пријавите пре него што одобрите привилегију %1$s приступ Вашем налогу %2$s.",
    "App token" : "Апликативни жетон",
    "Grant access" : "Одобри приступ",
    "Alternative log in using app token" : "Алтернативна пријава коришћењем апликативног жетона",
    "Account access" : "Приступ налогу",
    "You are about to grant %1$s access to your %2$s account." : "Управо ћете одобрити %1$s приступ Вашем %2$s налогу.",
    "Account connected" : "Налог повезан",
    "Your client should now be connected! You can close this window." : "Ваш клијент сада треба да је повезан! Можете затворити овај прозор.",
    "New password" : "Нова лозинка",
    "New Password" : "Нова лозинка",
    "This share is password-protected" : "Ово дељење је заштићено лозинком",
    "The password is wrong. Try again." : "Лозинка је погрешна. Покушајте поново.",
    "Two-factor authentication" : "Двофакторска провера идентитета",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Повећана сигурност је омогућена за овај налог. Одаберите други фактор за проверу идентитета:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Није могуће учитати ниједан метод двофакторске провере идентитета. Контактирајте администратора.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Двофакторска провера идентитета је захтевана, али није још подешена на Вашем налогу. Контактирајте администратора за помоћ.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Двофакторска провера идентитета је захтевана, али није још подешена на Вашем налогу. Контактирајте администратора да подеси двофакторску проверу идентитета.",
    "Set up two-factor authentication" : "Подеси двофакторску проверу идентитета",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Двофакторска провера идентитета је захтевана, али није још подешена на Вашем налогу. Или употребите Ваше резервне кôдове, или контактирајте администратора за помоћ.",
    "Use backup code" : "Користите резервни кôд",
    "Cancel log in" : "Поништите пријаву",
    "Setup two-factor authentication" : "Подеси двофакторску проверу идентитета",
    "Enhanced security is enforced for your account. Choose wich provider to set up:" : "Повећана сигурност је захтевана за овај налог. Одаберите провајдера којег желите да подесите:",
    "Error while validating your second factor" : "Грешка при провери Вашег другог фактора",
    "Access through untrusted domain" : "Приступ кроз небезбедни домен",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Контактирајте Вашег администратора. Ако сте Ви администратор, измените \"trusted_domains\" подешавање у config/config.php као у примеру config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Више информација о томе како ово подесити можете да нађете у %1$s документацији%2$s.",
    "App update required" : "Потребно ажурирање апликације",
    "%1$s will be updated to version %2$s" : "%1$s ће бити ажурирана на верзију %2$s",
    "These apps will be updated:" : "Следеће апликације ће бити ажуриране:",
    "These incompatible apps will be disabled:" : "Следеће некомпатибилне апликације ће бити онемогућене:",
    "The theme %s has been disabled." : "Тема %s је онемогућена.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Проверите да ли сте направили резервну копију фасцикли са подешавањима и подацима пре него што наставите.",
    "Start update" : "Почни ажурирање",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Да избегнете прекорачење времена одзива на већим инсталацијама, можете покренути следећу команду у инсталационом директоријуму:",
    "Detailed logs" : "Детаљни дневници",
    "Update needed" : "Потребно је ажурирање",
    "Please use the command line updater because you have a big instance with more than 50 users." : "Молимо користите ажурирање из конзоле пошто имате велики сервер са више од 50 корисника.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "За помоћ, погледајте <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">документацију</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Свестан сам да уколико наставим ажурирање преко веба да постоји ризик да захтеву истекне време за извршење и да то може да изазове губитак података, али имам резервну копију и знам како да је повратим у случају грешака.",
    "Upgrade via web on my own risk" : "Надогради преко веба на сопствену одговорност",
    "Maintenance mode" : "Режим одржавања",
    "This %s instance is currently in maintenance mode, which may take a while." : "Овај %s је тренутно у режиму одржавања што може потрајати.",
    "This page will refresh itself when the instance is available again." : "Ова страница ће се сама освежити када инстанца постане поново доступна.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Контактирајте администратора ако се порука понавља или се неочекивано појавила.",
    "Updated \"%s\" to %s" : "„%s“ ажуриран на %s",
    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Догодила се грешка приликом провере интегритета кода. Више информација...</a>",
    "Dismiss" : "Откажи",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Веза за ресетовање лозинке је послата на вашу е-пошту. Ако је не примите ускоро, проверите фасцикле за нежељену пошту.<br>Ако није ни тамо, контактирајте вашег администратора.",
    "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Ваши фајлови су шифровани. Не постоји ниједан начин да се Ваши подаци поврате ако се лозинка сад ресетује.<br /> Уколико нисте сигурни шта да радите, контактирајте Вашег администратора пре него што наставите.<br /> Да ли стварно желите да наставите?",
    "I know what I'm doing" : "Знам шта радим",
    "Sending email …" : "Слање е-поште…",
    "{name} below version {version} is installed, for stability and performance reasons it is recommended to update to a newer {name} version." : "{name} испод верзије {version} је инсталиран. Због стабилности и перформанси, препоручује се ажурирање на новију, {name} верзију.",
    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "PHP не може да чита /dev/urandom. Ово се баш не препоручује из сигурносних разлога. Можете наћи више информација у <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">документацији</a>.",
    "Copy URL" : "Копирај URL",
    "Enable" : "Укључи",
    "{{shareInitiatorDisplayName}} shared via link" : "{{shareInitiatorDisplayName}} је поделио преко везе",
    "{sharee} (group)" : "{sharee} (група)",
    "{sharee} (remote)" : "{sharee} (удаљено)",
    "{sharee} (email)" : "{sharee} (е-пошта)",
    "{sharee} (conversation)" : "{sharee} (разговор)",
    "The specified document has not been found on the server." : "Наведени документ није нађен на серверу.",
    "You can click here to return to %s." : "Кликните овде да се вратите на %s.",
    "SQLite will be used as database." : "СКуЛајт ће бити коришћен за базу података.",
    "For larger installations we recommend to choose a different database backend." : "За веће инсталације препоручујемо да изаберете другу базу података.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Нарочито ако се користи клијент у десктоп окружењу, коришћење СКуЛајта није препоручљиво.",
    "Wrong password." : "Погрешна лозинка.",
    "Please log in before granting %s access to your %s account." : "Прво се пријавите пре него што одобрите привилегију %s приступ Вашем налогу %s.",
    "You are about to grant %s access to your %s account." : "Управо ћете одобрити %s приступ Вашем %s налогу.",
    "Redirecting …" : "Преусмеравање ...",
    "Enhanced security is enabled for your account. Please authenticate using a second factor." : "Повећана сигурност је омогућена за овај налог. Проверите идентитет и другим фактором.",
    "Further information how to configure this can be found in the %sdocumentation%s." : "Више информација о томе како ово подесити можете да нађете у %s документацији%s.",
    "%s will be updated to version %s" : "%s ће бити ажурирана на верзију %s",
    "This page will refresh itself when the %s instance is available again." : "Ова страница ће се сама освежити када %s постане поново доступан.",
    "Thank you for your patience." : "Хвала Вам на стрпљењу.",
    "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Послали смо Вам е-пошту за ресетовање лозинке на е-мејл адресу која је повезана са овим налогом. Ако је не примите ускоро, проверите фасцикле за нежељену пошту.<br>Ако није ни тамо, контактирајте вашег администратора."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
